@@ -306,8 +306,7 @@ zenity_tree (ZenityData *data, ZenityTreeData *tree_data)
 	dialog = GTK_WIDGET(gtk_builder_get_object (builder, "zenity_tree_dialog"));
 	g_signal_connect (dialog, "response", G_CALLBACK(zenity_tree_dialog_response), data);
 
-	if (data->dialog_title)
-		adw_message_dialog_set_heading (ADW_MESSAGE_DIALOG(dialog), data->dialog_title);
+	zenity_util_setup_dialog_title (dialog, data);
 
 	if (data->modal)
 		gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
